//
//  AXController.h
//  Acrux
//
//  Created by Chetan Surpur on 12/24/09.
//  Copyright 2009 __MyCompanyName__. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import "AXLicense.h"

@class AXArchiver;
@class AXWindowController;

@interface AXController : NSObject {
}

+ (void) loadLicenseFromDisk;
+ (void) saveLicenseToDisk;
+ (void) displayActivationWindow; // sets values in activation window and displays it
+ (void) displayLicenseExpiredWindow; // sets values in activation window and displays it (when license is expired)
+ (AXLicense *) getLicense; // returns local license, can be used to check allowed usage left
+ (int) activate: (NSString *)licenseKey: (NSString *)userUniqueID; // activates product with given license key and user unique id (set license key to nil if activating a trial version)
/* return values for activate:
 * -1: Invalid access key
 * -2: Registration / activation failed due to connection issues
 * -3: Registration / activation failed because license key is invalid
 * -4: Activation failed because number of computers ran out
 * -5: No computer unique ID provided
 * -6: Trial activation failed because computer unique ID is already associated with another product
 * -7: Trial activation failed because trial license has expired
 * 0: Trial registration and activation succeeded, inserted a new row or reactivated existing trial. Returning license key.
 * 1: Activation succeeded, added new computer information to computerinfo table
 * 2: Activation succeeded, deactivated old license and activated new one
 */
+ (int) updateLocalLicenseInfo; // call this when you need to update the local version of the license with the server version (needs to be activated first)
/* return value for updateLocalLicenseInfo
** -1: Invalid access key
** -2: Connection error
** -3: No license key supplied
** -4: License not registered
** -5: License expired (time ran out)
** -6: License expired (maxed out uses or not enough uses after attempted increment)
** 1: License is valid (will also return complete license info)
*/
+ (int) updateRemoteLicenseInfo; // call this when you need to update the remote version of the license with the local version, returns true on update success (needs to be activated first)
/* return value for updateRemoteLicenseInfo
** -1: Invalid access key
** -2: Update failed due to connection issues
** -3: No license key provided
** -4: Update failed because license key doesn't exist
** 1: Update succeeded, made changes to database
*/
+ (int) checkIfEnoughUsesLeft: (int)attemptedUses; // call this when you need to check if the number of uses you are about to use can be supported by the license
/* return value for checkIfEnoughUsesLeft
 ** -1: Invalid access key
 ** -2: Connection error
 ** -3: No license key supplied
 ** -4: License not registered
 ** -5: License expired (time ran out)
 ** -6: License expired (not enough uses after attempted increment)
 ** 1: License is valid (will also return complete license info)
 */
+ (NSString *) getAppName;
+ (NSString *) getBuyURL;

@end
